//
//  ContentMainNewContentViewModel.swift
//  SodaLive
//
//  Created by klaus on 2023/12/11.
//

import Foundation
import Combine

final class ContentMainNewContentViewModel: ObservableObject {
    
    private let repository = ContentRepository()
    private var subscription = Set<AnyCancellable>()
    
    @Published var errorMessage = ""
    @Published var isShowPopup = false
    @Published var isLoading = false
    
    @Published var themeList = [String]()
    @Published var newContentList = [GetAudioContentMainItem]()
    
    @Published var selectedTheme = "전체" {
        didSet {
            newContentList.removeAll()
            getNewContentOfTheme()
        }
    }
    
    func getThemeList() {
        repository.getNewContentThemeList()
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { [unowned self] response in
                let responseData = response.data
                
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponse<[String]>.self, from: responseData)
                    
                    if let data = decoded.data, decoded.success {
                        self.themeList.removeAll()
                        self.themeList.append("전체")
                        self.themeList.append(contentsOf: data)
                    } else {
                        if let message = decoded.message {
                            self.errorMessage = message
                        } else {
                            self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        }
                        
                        self.isShowPopup = true
                    }
                } catch {
                    self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                    self.isShowPopup = true
                }
            }
            .store(in: &subscription)
    }
    
    func getNewContentOfTheme() {
        isLoading = true
        
        repository.getNewContentOfTheme(theme: selectedTheme == "전체" ? "" : selectedTheme)
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { [unowned self] response in
                self.isLoading = false
                let responseData = response.data
                
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponse<[GetAudioContentMainItem]>.self, from: responseData)
                    
                    if let data = decoded.data, decoded.success {
                        self.newContentList.removeAll()
                        self.newContentList.append(contentsOf: data)
                    } else {
                        if let message = decoded.message {
                            self.errorMessage = message
                        } else {
                            self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        }
                        
                        self.isShowPopup = true
                    }
                } catch {
                    self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                    self.isShowPopup = true
                }
            }
            .store(in: &subscription)
    }
}
