//
//  ContentMainRankingViewModel.swift
//  SodaLive
//
//  Created by klaus on 2023/12/11.
//

import Foundation
import Combine

final class ContentMainRankingViewModel: ObservableObject {
    
    private let repository = ContentRepository()
    private var subscription = Set<AnyCancellable>()
    
    @Published var errorMessage = ""
    @Published var isShowPopup = false
    @Published var isLoading = false
    
    @Published var dateString = ""
    @Published var contentRankingSortList = [String]()
    @Published var contentRankingItemList = [GetAudioContentRankingItem]()
    
    @Published var selectedContentRankingSort = "매출" {
        didSet {
            getContentRanking()
        }
    }
    
    func getContentRankingSortType() {
        repository.getContentRankingSortType()
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { [unowned self] response in
                let responseData = response.data
                
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponse<[String]>.self, from: responseData)
                    
                    if let data = decoded.data, decoded.success {
                        self.contentRankingSortList.removeAll()
                        self.contentRankingSortList.append(contentsOf: data)
                    } else {
                        if let message = decoded.message {
                            self.errorMessage = message
                        } else {
                            self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        }
                        
                        self.isShowPopup = true
                    }
                } catch {
                    self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                    self.isShowPopup = true
                }
            }
            .store(in: &subscription)
    }
    
    func getContentRanking() {
        isLoading = true
        
        repository.getContentRanking(page: 1, size: 12, sortType: selectedContentRankingSort)
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { [unowned self] response in
                self.isLoading = false
                let responseData = response.data
                
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponse<GetAudioContentRanking>.self, from: responseData)
                    
                    if let data = decoded.data, decoded.success {
                        dateString = "\(data.startDate)~\(data.endDate)"
                        self.contentRankingItemList.removeAll()
                        self.contentRankingItemList.append(contentsOf: data.items)
                    } else {
                        if let message = decoded.message {
                            self.errorMessage = message
                        } else {
                            self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        }
                        
                        self.isShowPopup = true
                    }
                } catch {
                    self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                    self.isShowPopup = true
                }
            }
            .store(in: &subscription)
    }
}
