//
//  CompletedSeriesViewModel.swift
//  SodaLive
//
//  Created by klaus on 2/22/25.
//

import Foundation
import Combine

final class CompletedSeriesViewModel: ObservableObject {
    private let repository = ContentMainTabSeriesRepository()
    private var subscription = Set<AnyCancellable>()
    
    @Published var errorMessage = ""
    @Published var isShowPopup = false
    @Published var isLoading = false
    
    @Published var rankCompleteSeriesList: [SeriesListItem] = []
    @Published var totalCount = 0
    
    var isLast = false
    var page = 1
    private let size = 20
    
    func getCompletedSeries() {
        if !isLast && !isLoading {
            isLoading = true
            
            repository.getCompletedSeries(page: page, size: size)
                .sink { result in
                    switch result {
                    case .finished:
                        DEBUG_LOG("finish")
                    case .failure(let error):
                        ERROR_LOG(error.localizedDescription)
                    }
                } receiveValue: { [unowned self] response in
                    let responseData = response.data
                    
                    do {
                        let jsonDecoder = JSONDecoder()
                        let decoded = try jsonDecoder.decode(ApiResponse<GetSeriesListResponse>.self, from: responseData)
                        
                        if let data = decoded.data, decoded.success {
                            page += 1
                            
                            if (data.items.count > 0) {
                                self.totalCount = data.totalCount
                                self.rankCompleteSeriesList = data.items
                            } else {
                                isLast = true
                            }
                        } else {
                            if let message = decoded.message {
                                self.errorMessage = message
                            } else {
                                self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                            }
                            
                            self.isShowPopup = true
                        }
                    } catch {
                        self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        self.isShowPopup = true
                    }
                    
                    self.isLoading = false
                }
                .store(in: &subscription)
        }
    }
}
