//
//  UserProfileSeriesView.swift
//  SodaLive
//
//  Created by klaus on 4/29/24.
//

import SwiftUI

struct UserProfileSeriesView: View {
    let creatorId: Int
    let items: [SeriesListItem]
    
    var body: some View {
        VStack(alignment: .leading, spacing: 13.3) {
            HStack(spacing: 0) {
                Text("시리즈")
                    .font(.custom(Font.bold.rawValue, size: 18.3))
                    .foregroundColor(Color.grayee)
                
                Spacer()
                
                Text("전체보기")
                    .font(.custom(Font.light.rawValue, size: 11.3))
                    .foregroundColor(Color.grayee)
                    .onTapGesture {
                        AppState.shared
                            .setAppStep(step: .seriesAll(creatorId: creatorId))
                    }
            }
            
            ScrollView(.horizontal, showsIndicators: false) {
                HStack(alignment: .top, spacing: 13.3) {
                    ForEach(0..<items.count, id: \.self) {
                        let item = items[$0]
                        SeriesListBigItemView(item: item, isVisibleCreator: false)
                    }
                }
            }
        }
    }
}

#Preview {
    UserProfileSeriesView(
        creatorId: 1,
        items: [
            SeriesListItem(
                seriesId: 1,
                title: "제목, 관심사,프로필+방장, 참여인원(어딘가..)",
                coverImage: "https://test-cf.sodalive.net/profile/default-profile.png",
                publishedDaysOfWeek: "매주 수, 토요일",
                isComplete: true,
                creator: SeriesListItemCreator(
                    creatorId: 1,
                    nickname: "creator",
                    profileImage: "https://test-cf.sodalive.net/profile/default-profile.png"
                ),
                numberOfContent: 10,
                isNew: true,
                isPopular: true
            ),
            SeriesListItem(
                seriesId: 1,
                title: "제목, 관심사,프로필+방장, 참여인원(어딘가..)",
                coverImage: "https://test-cf.sodalive.net/profile/default-profile.png",
                publishedDaysOfWeek: "매주 수, 토요일",
                isComplete: true,
                creator: SeriesListItemCreator(
                    creatorId: 1,
                    nickname: "creator",
                    profileImage: "https://test-cf.sodalive.net/profile/default-profile.png"
                ),
                numberOfContent: 10,
                isNew: true,
                isPopular: true
            )
        ])
}
