//
//  CanCouponViewModel.swift
//  SodaLive
//
//  Created by klaus on 2024/01/03.
//

import Foundation
import Combine

final class CanCouponViewModel: ObservableObject {
    
    private let repository = CanRepository()
    private var subscription = Set<AnyCancellable>()
    
    @Published var errorMessage = ""
    @Published var isShowPopup = false
    @Published var isLoading = false
    
    @Published var couponNumber = ""
    
    func useCoupon() {
        if !isLoading {
            isLoading = true
            repository.useCanCoupon(couponNumber: couponNumber)
                .sink { result in
                    switch result {
                    case .finished:
                        DEBUG_LOG("finish")
                    case .failure(let error):
                        ERROR_LOG(error.localizedDescription)
                    }
                } receiveValue: { [unowned self] response in
                    self.isLoading = false
                    let responseData = response.data
                    
                    do {
                        let jsonDecoder = JSONDecoder()
                        let decoded = try jsonDecoder.decode(ApiResponseWithoutData.self, from: responseData)
                        
                        if decoded.success {
                            self.errorMessage = "해당 쿠폰의 캔이 충전되었습니다."
                            
                            DispatchQueue.main.asyncAfter(deadline: .now() + 1) {
                                AppState.shared.setAppStep(step: .canStatus(refresh: {}))
                            }
                        } else {
                            if let message = decoded.message {
                                self.errorMessage = message
                            } else {
                                self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                            }
                        }
                        
                        self.isShowPopup = true
                    } catch {
                        self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        self.isShowPopup = true
                    }
                }
                .store(in: &subscription)
        }
    }
    
}
